@@ -1,12 +1,16 @@
 module Main where
 
-import           Data.Monoid
 import qualified Data.Text as T
 
 import Test.Framework (Test, defaultMain, testGroup)
 import Test.Framework.Providers.HUnit (testCase)
 import Test.HUnit (assertEqual)
 
+#if !(MIN_VERSION_base(4,11,0))
+  -- this is redundant starting with base-4.11 / GHC 8.4
+import Data.Semigroup
+#endif
+
 import qualified NLP.Miniutter.English as MU
 
 main :: IO ()
@@ -80,9 +84,9 @@ testMakePhrasePlural = testGroup "plural form Part constructors"
   [ tp [MU.Ws "dog"]        "dogs"
   , tp [MU.Ws "dogs"]       "dogses"
   , tp [MU.Ws "blue dog"]   "blue dogs"
-  , tp [MU.Ws "blue dog  "] "blue dog  "
-  , tp [MU.Ws "blue dog."]  "blue dog."
-  , tp [MU.Ws "blue dog%"]  "blue dog%"
+  , tp [MU.Ws "blue dog  "] "blue dogs  "
+  , tp [MU.Ws "blue dog."]  "blue dogs."
+  , tp [MU.Ws "blue dog%"]  "blue dogs%"
   , tp [MU.Ws "bitch"]      "bitches"
   , tp [MU.Ws "the fish"]   "the fishes"
   , tp [MU.Ws "miss"]       "misses"
@@ -109,14 +113,14 @@ testMakePhrasePlural = testGroup "plural form Part constructors"
   , tp [MU.Ws "dwarf"]      "dwarfs"
   , tp [MU.Ws "hoof"]       "hooves"
   , tp [MU.Ws "elf"]        "elves"
---, tp [MU.Ws "staff"]      "staves"  -- depends on the meaning :(
+  , tp [MU.Ws "staff"]      "staves"  -- though depends on the meaning :(
   , tp [MU.Ws "child"]      "children"
   , tp [MU.Ws "foot"]       "feet"
   , tp [MU.Ws "goose"]      "geese"
   , tp [MU.Ws "louse"]      "lice"
   , tp [MU.Ws "man"]        "men"
   , tp [MU.Ws "mouse"]      "mice"
-  , tp [MU.Ws "tooth"]      "teeth"
+  , tp [MU.Ws "Tooth"]      "Teeth"
   , tp [MU.Ws "woman"]      "women"
   , tp [MU.Ws "buffalo"]    "buffalo"
   , tp [MU.Ws "deer"]       "deer"
@@ -125,11 +129,11 @@ testMakePhrasePlural = testGroup "plural form Part constructors"
   , tp [MU.Ws "bison"]      "bison"
   , tp [MU.Ws "salmon"]     "salmon"
   , tp [MU.Ws "pike"]       "pike"
-  , tp [MU.Ws "trout"]      "trout"
+  , tp [MU.Ws "Trout"]      "Trout"
   , tp [MU.Ws "swine"]      "swine"
   , tp [MU.Ws "aircraft"]   "aircraft"
   , tp [MU.Ws "watercraft"] "watercraft"
-  , tp [MU.Ws "spacecraft"] "spacecraft"
+  , tp [MU.Ws "Spacecraft"] "Spacecraft"
   , tp [MU.Ws "hovercraft"] "hovercraft"
   , tp [MU.Ws "information"]                  "information"
   , tp [MU.Ws (MU.String "dog blue")]         "dog blues"
@@ -139,9 +143,9 @@ testMakePhrasePlural = testGroup "plural form Part constructors"
   , tp [MU.Ws (MU.Ord 1)]                     "1sts"
   , tp [MU.Ws (MU.AW "elf")]                  "an elves"
   , tp [MU.Ws (MU.WWandW ["dog", "eagle", "parrot"])]
-                                              "dog, eagle and parrots"
+                                              "dogs, eagle and parrot"
   , tp [MU.Ws (MU.WWxW "and also" ["dog", "eagle", "parrot"])]
-                                              "dog, eagle and also parrots"
+                                              "dogs, eagle and also parrot"
   , tp [MU.Ws (MU.Wown "uncle")]              "uncle'ses"
   , tp [MU.Ws (MU.WownW "uncle" "dog")]       "uncle's dogs"
   , tp [MU.Ws (MU.Phrase ["uncle", "dog"])]   "uncle dogs"
@@ -170,7 +174,7 @@ testMakePhraseNumber = testGroup "number Part constructors"
   , tp [MU.Car1Ws 1 "blue dog"]        "blue dog"
   , tp [MU.CarWs 1 "blue dog"]         "1 blue dog"
   , tp [MU.Car1Ws 2 "blue elf"]        "2 blue elves"
-  , tp [MU.CardinalWs 2 " dog "]       "two  dog "
+  , tp [MU.CardinalWs 2 " dog "]       "two  dogs "
   , tp [MU.CarAWs 3 "leaf"]            "3 leaves"
   , tp [MU.CardinalAWs 0 "sheep"]      "no sheep"
   , tp [MU.CardinalAWs 1 "sheep"]      "a sheep"
@@ -252,7 +256,7 @@ testMakePhraseEnumeration = testGroup "enumeration and collection"
 testMakePhrasePossesive :: Test
 testMakePhrasePossesive = testGroup "the possesive form"
   [ tp [MU.Wown (MU.String "uncle")]   "uncle's"
-  , tp [MU.Wown (MU.String " uncle ")] " uncle "
+  , tp [MU.Wown (MU.String " uncle ")] " uncle's "
   , tp [MU.Wown ""]                    ""
   , tp [MU.Wown " "]                   " "
   , tp [MU.Wown "miss"]                "miss'"
@@ -268,7 +272,7 @@ testMakePhrasePossesive = testGroup "the possesive form"
   , tp [MU.Wown "We"]                  "Ours"
   , tp [MU.Wown "they"]                "theirs"
   , tp [MU.WownW (MU.String "uncle") (MU.String "dog")] "uncle's dog"
-  , tp [MU.WownW " uncle " "dog"]                       " uncle  dog"
+  , tp [MU.WownW " uncle " "dog"]                       " uncle's  dog"
   , tp [MU.WownW "I" ""]                                "my"
   , tp [MU.WownW "" "dog"]                              "dog"
   , tp [MU.WownW "" ""]                                 ""
@@ -295,7 +299,7 @@ testMakePhrasePossesive = testGroup "the possesive form"
   , tp [MU.Wown $ MU.Wown $ MU.Wown $ MU.Wown "it"]     "its's'"
   , tp [MU.Wown (MU.SubjectVerb MU.Sg3rd MU.Why "I" "be")] "am mine"
   , tp [MU.Wown " do   I"]                              " do   mine"
-  , tp [MU.Wown " do   I "]                             " do   I "
+  , tp [MU.Wown " do   I "]                             " do   mine "
   ]
 
 testMakePhraseSubjectVerb :: Test
